@@ -108,6 +108,7 @@ def import_all_unsend_upstream_data_function(credential_info=None, dataset_name=
     
     import_count    = len(upstream_data_list)
     errors          = []    
+    imported_count  = 0
     
     for u in upstream_data_list:
         
@@ -130,20 +131,19 @@ def import_all_unsend_upstream_data_function(credential_info=None, dataset_name=
         
         if len(__errors)>0:
             errors.extend(__errors)
-    
-    if errors==[]:
-        with db_client.context():
-            for u in upstream_data_list:
+        else:
+            with db_client.context():
                 u.is_sent = True
                 u.put()
+                logger.debug("New rows have been added")
                 
-                
-        logger.debug("New rows have been added")
+            imported_count+=1
+            
+    if errors==[]:
+        logger.debug('imported_count=%d', imported_count)
     else:
         logger.debug("Encountered errors while inserting rows: {}".format(errors))
     
-    logger.debug('import_count=%d', import_count)
-    
     return next_cursor
     
 @import_upstream_data_bp.route('/upstream/data-content/<upstream_data_key>')
